# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["RampType"]

RampType: TypeAlias = Literal["gre", "gre_interconnect", "mpls_interconnect", "mconn", "ipsec"]
