# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ....._models import BaseModel

__all__ = ["FindingExportResponse"]


class FindingExportResponse(BaseModel):
    """Information about an export job."""

    id: str
    """Unique identifier for the export job."""

    status: Literal["Pending", "Success", "Failure", "Rescheduled", "In-Progress"]
    """Status of an export job."""

    type: Literal["finding", "findingInstance", "content", "remediationJob"]
    """Type of export job."""

    user_id: str
    """ID of the export-requesting user."""

    download_url: Optional[str] = None
    """
    The URL by which the successfully created export can be downloaded by the end
    users.
    """

    errors: Optional[str] = None
    """Contains information on errors which may have occurred during export creation."""

    file_name: Optional[str] = None
    """The base name of the file that is/was generated by the export job."""

    file_path: Optional[str] = None
    """
    The full path of the file that is stored within external storage (currently R2).
    """
