# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .dmarc_report_edit_params import DMARCReportEditParams as DMARCReportEditParams
from .dmarc_report_get_response import DMARCReportGetResponse as DMARCReportGetResponse
from .dmarc_report_edit_response import DMARCReportEditResponse as DMARCReportEditResponse
