# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["FindingTuneSeverityParams"]


class FindingTuneSeverityParams(TypedDict, total=False):
    account_id: Required[str]

    new_severity: Required[Literal[1, 2, 3, 4]]
    """The numeric severity value to apply to the finding."""
