# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .tenant_custom_nameservers import (
    TenantCustomNameserversResource,
    AsyncTenantCustomNameserversResource,
    TenantCustomNameserversResourceWithRawResponse,
    AsyncTenantCustomNameserversResourceWithRawResponse,
    TenantCustomNameserversResourceWithStreamingResponse,
    AsyncTenantCustomNameserversResourceWithStreamingResponse,
)

__all__ = [
    "TenantCustomNameserversResource",
    "AsyncTenantCustomNameserversResource",
    "TenantCustomNameserversResourceWithRawResponse",
    "AsyncTenantCustomNameserversResourceWithRawResponse",
    "TenantCustomNameserversResourceWithStreamingResponse",
    "AsyncTenantCustomNameserversResourceWithStreamingResponse",
]
