# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .origin_tls_compliance_mode_edit_params import (
    OriginTLSComplianceModeEditParams as OriginTLSComplianceModeEditParams,
)
from .origin_tls_compliance_mode_get_response import (
    OriginTLSComplianceModeGetResponse as OriginTLSComplianceModeGetResponse,
)
from .origin_tls_compliance_mode_edit_response import (
    OriginTLSComplianceModeEditResponse as OriginTLSComplianceModeEditResponse,
)
from .origin_tls_compliance_mode_update_params import (
    OriginTLSComplianceModeUpdateParams as OriginTLSComplianceModeUpdateParams,
)
from .origin_tls_compliance_mode_delete_response import (
    OriginTLSComplianceModeDeleteResponse as OriginTLSComplianceModeDeleteResponse,
)
from .origin_tls_compliance_mode_update_response import (
    OriginTLSComplianceModeUpdateResponse as OriginTLSComplianceModeUpdateResponse,
)
